Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(375)

Unified Diff: pkg/analysis_server/lib/plugin/occurrences.dart

Issue 1337143002: Add OCCURRENCES_CONTRIBUTOR_EXTENSION_POINT_ID. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/lib/plugin/occurrences.dart
diff --git a/pkg/analysis_server/lib/plugin/navigation.dart b/pkg/analysis_server/lib/plugin/occurrences.dart
similarity index 58%
copy from pkg/analysis_server/lib/plugin/navigation.dart
copy to pkg/analysis_server/lib/plugin/occurrences.dart
index 23603f06f64e87eb893e38918fa0abc430d1f97d..5339ccc4cc08fb059b7fe40a63a653eefa0818c2 100644
--- a/pkg/analysis_server/lib/plugin/navigation.dart
+++ b/pkg/analysis_server/lib/plugin/occurrences.dart
@@ -4,19 +4,19 @@
/**
* Support for client code that extends the analysis server by adding new
- * navigation contributors.
+ * occurrences contributors.
*/
-library analysis_server.plugin.navigation;
+library analysis_server.plugin.occurrences;
-import 'package:analysis_server/analysis/navigation/navigation_core.dart';
+import 'package:analysis_server/analysis/occurrences_core.dart';
import 'package:analysis_server/src/plugin/server_plugin.dart';
import 'package:plugin/plugin.dart';
/**
* The identifier of the extension point that allows plugins to register
* navigation contributors. The object used as an extension must be
* a [NavigationContributor].
*/
-final String NAVIGATION_CONTRIBUTOR_EXTENSION_POINT_ID = Plugin.join(
+final String OCCURRENCES_CONTRIBUTOR_EXTENSION_POINT_ID = Plugin.join(
ServerPlugin.UNIQUE_IDENTIFIER,
- ServerPlugin.NAVIGATION_CONTRIBUTOR_EXTENSION_POINT);
+ ServerPlugin.OCCURRENCES_CONTRIBUTOR_EXTENSION_POINT);

Powered by Google App Engine
This is Rietveld 408576698
@@ -4,19 +4,19 @@
/**
* The identifier of the extension point that allows plugins to register
- * navigation contributors. The object used as an extension must be
- * a [NavigationContributor].
+ * element occurrences. The object used as an extension must be
+ * a [OccurrencesContributor].
*/